# import the individual widgets

from combo import ComboWidget
from datetime import DateTimeWidget
from deadlines import DeadlinesWidget
from record import RecordWidget
from records import RecordsWidget
from url import UrlWidget
from email import EmailWidget 
from formattablename import FormattableNameWidget
from formattablenames import FormattableNamesWidget
from comment import CommentWidget
from remotetext import RemoteTextWidget
from smartemail import SmartEmailWidget
from labeledurl import LabeledUrlWidget
