# import the individual fields

from datetime import DateTimeField
from url import UrlField
from email import EmailField
from record import RecordField
from records import RecordsField
from record_examples import SimpleNameField, LocationField,\
     AddressField, ContactField, NetAddressField, LabeledUrlField
from records_examples import MultipleNamesField, PhoneNumbersField
from formattablename import FormattableNameField
from formattablenames import FormattableNamesField
from comment import CommentField
from remotetext import RemoteTextField
from smartemail import SmartEmailField
